<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" version="1.0" encoding="ISO-8859-1" omit-xml-declaration="no" indent="no" media-type="text/html"/>
	<!-- An XSL template for displaying metadata in ECS.
     Based on 
     Copyright (C) 2000 Environmental Systems Research Institute, Inc. (ESRI)
	
     Revision History: Created 01/17/2002 rabi

-->

<!-- global variables for location of the down/left arrow gifs -->
<xsl:variable name="downgif">../down.gif</xsl:variable>
<xsl:variable name="leftgif">../left.gif</xsl:variable>

	<xsl:template match="/">
		<HTML>
			<HEAD>
				<STYLE>
					<!-- body -->
        BODY {background-color:#FBFFFF; margin:0.25in; 
              font-size:10pt; font-family:Arial,sans-serif}
        <!-- title -->
        H1   {margin-left:0.05in; position:relative; top:-6; text-align:center;
              font-weight:bold; font-size:14; font-family:Verdana,sans-serif; color:#006400}
        <!-- data type -->
        H2   {margin-left:0.25in; position:relative; top:-16; text-align:center;
              font-size:13; font-family:Verdana,sans-serif; color:#006400}

        <!-- "tabs" table -->
					<!-- table style 
        TABLE  {position:relative; top:-10; valign:top; table-layout:fixed; 
                border-collapse:collapse}
		-->
        <!-- table row style -->
        TD   {text-align:center}
        <!-- table cell style -->
        TD   {font-weight:normal; font-size:10pt; border-color:#6495ED}
        <!-- table row style -->
        TH   {text-align:center}
        <!-- table cell style -->
        TH   {font-weight:bold; font-size:9pt; font-color:#CC0000;font-family:Verdana,sans-serif; border-color:#6495ED}
        <!-- selected tab -->
        .tsel  {color:#FFFFFF; background-color:#6495ED}
        <!-- unselected tab -->
        .tun   {color:#00008B; background-color:#B8DEFA}
        <!-- unselected tab hilite -->
        .tover {color:#0000CD; background-color:#B8E6FF; cursor:hand}
        <!-- properties box -->
        .f   {background-color:#FFFFFF; border:'1.5pt solid #6495ED'; 
              position:relative; top:-10}

        <!-- headings -->
					<!-- group heading -->
        .ph1  {color:#2E8B57; font-weight:bold; cursor:}
        <!-- group heading indented -->
        .ph2  {margin-left:0.2in; color:#2E8B57; font-weight:bold; cursor:}
        <!-- group heading hilite -->
        .pover1 {color:#006000; font-weight:bold; cursor:hand}
        <!-- group heading hilite indented -->
        .pover2 {margin-left:0.2in; color:#006000; font-weight:bold; cursor:hand}

        <!-- values -->
					<!-- property name -->
        .pn  {color:#00008B; font-weight:bold}
        <!-- property value -->
        .pv  {font-family:Verdana,sans-serif; line-height:135%;
              color:#191970; margin:0in 0.15in 0.75in 0.15in}
        <!-- expanded properties -->
        .pe1  {margin-left:0.2in}
        <!-- expanded properties entity indent -->
        .pe2  {margin-left:0.25in; font-weight:normal; color:#191970;}
        <!-- expanded long text -->
        .lt  {line-height:115%}
        <!-- lists of comma-separated elements -->
        .lt2  {line-height:115%; margin-bottom:1mm}
        <!-- indented spatial reference parameters -->
        .sr1  {margin-left:0in}
        .sr2  {margin-left:0.2in}
        .sr3  {margin-left:0.4in}
        .srh1  {color:#00008B; font-weight:bold; margin-left:0in}
        .srh2  {color:#00008B; font-weight:bold; margin-left:0.2in}

        <!-- search results -->
        .name   {margin-left:0.05in; position:relative; top:-6; text-align:center;
                 font-weight:bold; font-size:18; font-family:Verdana,sans-serif; color:#006400}
        .sub   {margin-left:0.25in; text-align:center; position:relative; top:3; 
                font-weight:bold; font-size:13; font-family:Verdana,sans-serif; color:#006400}
        .search   {margin:0in 0.15in 0.75in 0.15in; 
                   color:#191970; font-family:Verdana,sans-serif; font-size:13}
        .head   {color:#006400}
        .mytable   {color:#006400;position:relative; top:-10; valign:top; table-layout:; border-collapse:collapse}
        .fixedtable  {position:relative; top:-10; valign:top; table-layout:fixed; border-collapse:collapse}
      </STYLE>
	  <SCRIPT LANGUAGE="JavaScript">
	  <xsl:comment>

      // JRB - functions based on W3C DOM, so they ought to work
      // in any recent browser (MS IE 5+, Netscape 5+)
      //
      //
      // Returns the first child of par whose nodeName is stuff
      function findchild(par, stuff) {
         for(var i = 0; i != par.childNodes.length; i++) {
	    if(par.childNodes[i].nodeName == stuff) {
	       //alert(par.childNodes[i].nodeName);
	       return par.childNodes[i];
	    }
         }
      }
      // These functions assume a set of named tabs that function
      // as links to a set of named blocks.  These named blocks
      // contain one or more arrow blocks of the form (in S-expression
      // form to hide them from the brain-dead eye of XSLT):
      // (div
      //  (div style="crap for arrows"
      //   (a onClick="flipArrow(this);" (img border="0" src="left.gif")))
      //  Title of Block
      //  (div style = "display:none" controlled="yes"
      //    ... Contents of controlled block
      //  ))
      //
      // flipArrow(link) toggles the arrow in its IMG sibling, then
      // reaches up to all its DIV siblings with the 'controlled'
      // attribute and toggles their style.display attributes
      function flipArrow(link) {
         var imgChild = findchild(link, "IMG");
	 var newDisplay;
	 var parentBlock = link.parentNode.parentNode;
	 if(imgChild.src == downSrc) {
	    imgChild.src = leftSrc;
	    newDisplay = 'none';
	    }
	 else {    
	    imgChild.src = downSrc;
	    newDisplay = 'block';
	 }
	 for(var i = 0; i != parentBlock.childNodes.length; i++) {
	    if(parentBlock.childNodes[i].getAttribute('controlled') == "yes") {
	       parentBlock.childNodes[i].style.display = newDisplay;
	    }
	 }
         return false;
      }
      
      // flipTab(link) reaches up from the link to the enclosing tab,
      // gets the name of the associated block on the myblock attribute,
      // and using the values of globals currentTab and currentBlock
      // makes everything highlighed/unhighlighted and visible/invisible
      function flipTab(mylink) {
         var mytab = mylink.parentNode;
	 var myblockname = mytab.getAttribute('myblock');
	 if( mytab != currentTab ) {
            // Turn the old selected tab/block off
	    currentTab.className = 'tun';
	    currentBlock.style.display = 'none';
	    // Point at the newly selected tab/block
	    currentTab = mytab;
	    currentBlock =  document.getElementById(myblockname);
	    // And turn them on
	    currentTab.className = 'tsel';
	    currentBlock.style.display = 'block';
	 }
      }

      // initialize() sets the globals currentTab and currentBlock to match
      // the initial HTML, and it reaches inside the never-displayed first
      // DIV block to set up pointers to the down and left arrows
      function initialize() {
         currentTab = document.getElementById('DescTab');
	 currentBlock = document.getElementById('Description');
	 downSrc = document.getElementById('DOWNIMG').src;
	 leftSrc = document.getElementById('LEFTIMG').src;
      }
      </xsl:comment>
				</SCRIPT>
			</HEAD>
<BODY onload="initialize();" oncontextmenu="return false">
<DIV style="display:none">
  <IMG ID='DOWNIMG' src = "{$downgif}"/>
  <IMG ID='LEFTIMG' src = "{$leftgif}"/>
</DIV>
 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:when test="current()[not(GranuleMetaDataFile)]">
   <DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
    This document does not contain information that can be displayed with the stylesheet.
   </DIV>
  </xsl:when>
  <xsl:otherwise>
  <xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData/ShortName[. != '']">
			<H2>
					<xsl:value-of select="."/> 
			</H2>
 </xsl:for-each>
			<H3>
				Inventory Metadata
			</H3>
						<!-- Set up the tabs -->
<TABLE cols="8" frame="void" rules="cols" width="635" height="28" CLASS="fixedtable">
							<COL WIDTH="125"/>
							<COL WIDTH="65"/>
							<COL WIDTH="75"/>
							<COL WIDTH="135"/>
							<COL WIDTH="75"/>
							<COL WIDTH="60"/>
							<COL WIDTH="60"/>
							<COL WIDTH="80"/>
<TR height="28">
<!--
	<TD  ID="ColDescTab" myblock= "CollectionDescriptionClass" CLASS="tsel" TITLE="Click for details about the processing Level data"><a onClick="flipTab(this);">Collection Description</a></TD>
-->
	<!-- The ID of this tab is used above -->
	<TD ID="DescTab" myblock= "Description" CLASS="tsel" TITLE="Click to see a description of the data"><a onClick="flipTab(this);">ECS Granule Data </a></TD>
	<TD myblock= "Spatial" CLASS="tun" TITLE="Click for details about the spatial data"><a onClick="flipTab(this);">Spatial</a></TD>
	<TD myblock= "Temporal" CLASS="tun" TITLE="Click for details about the temporal data"><a onClick="flipTab(this);">Temporal</a></TD>
	<TD myblock= "MeasuredParameters" CLASS="tun" TITLE="Click for details about the temporal data"><a onClick="flipTab(this);">Measured Parameters</a></TD>

<!--
	<TD myblock= "ProcessingQA" CLASS="tun" TITLE="Click for details about the processing QA data"><a onClick="flipTab(this);">ProcessingQA</a></TD>
	<TD myblock= "Review" CLASS="tun" TITLE="Click for details about the review data"><a onClick="flipTab(this);">Review</a></TD>
	<TD myblock= "AnalysisSource" CLASS="tun" TITLE="Click for details about the Analysis Source data"><a onClick="flipTab(this);">Analysis Source</a></TD>
-->
	<TD ID="PlatformTab" myblock= "Platform"  CLASS="tun" TITLE="Click for details about the platform data"><a onClick="flipTab(this);">Platform</a></TD>
	<TD myblock= "DisciplineTopicParameters" CLASS="tun" TITLE="Click for details about the discipline topic parameters data"><a onClick="flipTab(this);">PSAs</a></TD>
	<TD myblock= "Other" CLASS="tun" TITLE="Click for details about the Review, Analysis Source and other data"><a onClick="flipTab(this);">Other</a></TD>
	<TD myblock= "DataLinks" CLASS="tun" TITLE="Click for links to the whole data file and its fields"><a onClick="flipTab(this);">Data Links</a></TD>
<!--
	<TD ID="AttribTab" myblock= "Attributes"  CLASS="tun" TITLE="Click for details about the attribute data"><a onClick="flipTab(this);">Attributes</a></TD>
-->
	</TR>
</TABLE>
<DIV ID="Group" CLASS="f">
<!-- Define the box which will contain the contents of the current tab -->
	<!-- CollectionDescriptionClass Tab -->
<!--
	<DIV ID="CollectionDescriptionClass" CLASS="pv" STYLE="display:block">
	<BR/>
	<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData">
-->
	<!-- Show contents of CollectionDescriptionClass tab -->
<!--
	<DIV STYLE="margin-left:0.2in" controlled="yes">
	<B>Collection Description Class</B>
	</DIV>
	<DIV STYLE="margin-left:0.4in">
	<I>Short Name = </I>
	<SPAN STYLE="color:#999999">
	<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData/ShortName" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</SPAN>
	</DIV>
	<xsl:variable name="versionid" select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData/VersionId"/>
	<xsl:if test="count($versionid) > 0">
	<DIV STYLE="margin-left:0.4in" STYLE="display:block">
	<I>Version ID = </I>
	<SPAN STYLE="color:#999999">
	<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData/VersionId" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</SPAN>
	</DIV>
	</xsl:if>
	
	</xsl:when>
-->
	<!-- If nothing to show in processing level tab, show message -->
<!--
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
              No collection description information is available.
        </DIV>
	</xsl:otherwise>
	</xsl:choose>
	</DIV>
-->
	<!-- Description Tab -->
	<DIV ID="Description" CLASS="pv" STYLE="display:block">
	<BR/>
    <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule[( 
                   LocalGranuleID | SizeMBDataGranule | ProductionDateTime | LocalVersionID | ReprocessingPlanned | ReprocessingActual |DayNightFlag ) 
    ] "  >
<!-- Show contents of Description tab -->

<DIV>
	<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData">
	<!-- Show contents of CollectionDescriptionClass tab -->
	<DIV STYLE="margin-left:0.0in" controlled="yes">
	<B>Collection Description Class</B>
	</DIV>
	<DIV STYLE="margin-left:0.2in">
	<I>Short Name = </I>
	<SPAN STYLE="color:#999999">
	<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData/ShortName" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</SPAN>
	</DIV>
	<DIV STYLE="margin-left:0.2in">
	<I>Version ID = </I>
	<SPAN STYLE="color:#999999">
	<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/CollectionMetaData/VersionId" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</SPAN>
	</DIV>
	</xsl:when>
	<!-- If nothing to show in processing level tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
              No collection description information is available.
        </DIV>
	</xsl:otherwise>
	</xsl:choose>
</DIV>
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="cdc"/></a></DIV>
<DIV CLASS="ph2">ECS Granule Data</DIV>
<DIV CLASS="ph2" style="display:none" controlled="yes">
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
</DIV>
</DIV>
	</xsl:when>
    <!-- If nothing to show in Description tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
          No descriptive information about the data is available.
    </DIV>
   </xsl:otherwise>
  </xsl:choose>
</DIV>

<!-- Spatial Tab -->
<DIV ID="Spatial" class="pv" STYLE="display:none">
			<BR/>
<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer">
 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/GranuleLocality">
   <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/GranuleLocality" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
   </xsl:when>
   <xsl:otherwise>
  <DIV STYLE="text-align:center; color:#6495ED">
              No granule locality information is is available.
  </DIV>
   </xsl:otherwise>
  </xsl:choose>

  <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer">
   <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
   </xsl:when>
   <xsl:otherwise>
  <DIV STYLE="text-align:center; color:#6495ED">
              No horizontal spatial information is is available.
  </DIV>
   </xsl:otherwise>
  </xsl:choose>

 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
   <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/VerticalSpatialDomain">
   <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/VerticalSpatialDomain" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
   </xsl:when>
   <xsl:otherwise>
  <DIV STYLE="text-align:center; color:#6495ED">
              No vertical spatial information is available.
  </DIV>
   </xsl:otherwise>
  </xsl:choose>	
 </xsl:when>
 <!-- If nothing to show in Spatial tab, show message -->
 <xsl:otherwise>
  <DIV STYLE="text-align:center; color:#6495ED">
              No detailed spatial information is is available.
  </DIV>
 </xsl:otherwise>
</xsl:choose>
<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/OrbitCalculatedSpatialDomain">
  <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/OrbitCalculatedSpatialDomain" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
 </xsl:when>
 <xsl:otherwise>
  <DIV STYLE="text-align:center; color:#6495ED">
              No orbit calculated spatial information is is available.
  </DIV>
 </xsl:otherwise>
</xsl:choose>

	<BR/>
</DIV>


  <!-- Temporal Tab -->
	<DIV ID="Temporal" CLASS="pv" STYLE="display:none">
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
		<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime">
		<!-- Show contents of temporal tab -->
		<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
		</xsl:when>
	<!-- If nothing to show in Default Package tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No temporal information is available.
     </DIV>
	<BR/>
	</xsl:otherwise>
	</xsl:choose>
	<BR/>
	</DIV>




	<!-- Discipline Topic Parameters Tab -->
	<DIV ID="DisciplineTopicParameters" class="pv" STYLE="display:none">
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/PSAs">
		<!-- Show contents of Discipline Topic Parameters tab -->
		<DIV CLASS="pe2" STYLE="margin-left=0.2in">
			<B> Parameters Specific Attributes</B>
			<DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
			<table border="1" width="80%" align="center" CLASS="mytable">
							<tr>
								<th> Class </th>
								<th> Name </th>
								<th> Value </th>
							</tr>
		<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/PSAs/PSA" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
		</table>
		</DIV>
	</DIV>
	</xsl:when>
	<!-- If nothing to show in Discipline Topic Parameters tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No detailed attribute information is available.
    </DIV>
	</xsl:otherwise>
    </xsl:choose>
	<BR/>
	</DIV>

	<!-- Data Links Tab -->
	<DIV ID="DataLinks" class="pv" STYLE="display:none">
	<BR/>
	<xsl:variable name="opendaplinks" select="document($linksdoc)"/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<xsl:when test="$opendaplinks">
		<!-- Show contents of Data Links tab -->
		<DIV CLASS="pe2" STYLE="margin-left=0.2in">
			<B>Links to Data Fields</B>
			<DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
			<table>
			<tr>
			 <th>Whole File</th>
			 <td><a href="{$opendaplinks/OpenDAPLinks/WholeFile/@dods}">OpenDAP</a></td>
			 <td><a href="{$opendaplinks/OpenDAPLinks/WholeFile/@raw}">HDF-EOS</a></td>
			</tr>
			</table>
			<BR/>
			Byte Order of Binary Fields: <B><xsl:value-of select="$opendaplinks/OpenDAPLinks/FieldLinks/ByteOrder/@order"/></B>
			<BR/>

			<xsl:variable name="geofields" select="$opendaplinks/OpenDAPLinks/FieldLinks/GeoFields"/>			<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

			<xsl:when test="$geofields">
			<BR/><B>Georeference Fields</B><BR/>
                        <table>
                          <tr><th>Name</th> <th>Data Type (size)</th> <th>OpenDAP</th> <th>Binary</th></tr>
                          <xsl:for-each select="$geofields/GeoField">
                              <tr><td><xsl:value-of select="@name"/></td>
                                  <td><xsl:value-of select="@type"/></td>
                                  <td><a href="{@dodslink}">link</a></td>
                                  <td><a href="{@datalink}">link</a></td>
                              </tr>
                          </xsl:for-each>
                        </table>
			</xsl:when>
			</xsl:choose>

			<BR/>

			<xsl:variable name="datafields" select="$opendaplinks/OpenDAPLinks/FieldLinks/DataFields"/>			<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

			<xsl:when test="$datafields">
			<BR/><B>Data Fields</B><BR/>
                        <table>
                          <tr><th>Name</th> <th>Data Type (size)</th> <th>OpenDAP</th> <th>Binary</th></tr>
                          <xsl:for-each select="$datafields/DataField">
                              <tr><td><xsl:value-of select="@name"/></td>
                                  <td><xsl:value-of select="@type"/></td>
                                  <td><a href="{@dodslink}">link</a></td>
                                  <td><a href="{@datalink}">link</a></td>
                              </tr>
                          </xsl:for-each>
                        </table>
			</xsl:when>
			</xsl:choose>
		</DIV>
	</DIV>
	</xsl:when>
	<!-- If nothing to show in Data Links tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No data links are available.
    </DIV>
	</xsl:otherwise>
    </xsl:choose>
	<BR/>
	</DIV>

	<!-- MeasuredParameters Tab -->
	<DIV ID="MeasuredParameters" class="pv" STYLE="display:none">
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter">
		<!-- Show contents of Measured Parameters tab -->
		<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</xsl:when>
	<!-- If nothing to show in Measured Parameters tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No measured parameter information is available.
	</DIV>
	</xsl:otherwise>
    </xsl:choose>
	</DIV>

	<DIV ID="Other" class="pv" STYLE="display:none">

	<!-- ProcessingQATab 
	<DIV ID="ProcessingQA" class="pv" STYLE="display:none">
-->
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA">
		<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</xsl:when>
	<!-- If nothing to show in ProcessingQA tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No processingQA information is available.
	</DIV>
	</xsl:otherwise>
    </xsl:choose>
		<DIV STYLE="text-align:center; color:blue;margin-left=0.6in">
			<B>________________</B>
		</DIV>

	<!-- 
	</DIV>

	Analysis Source
	<DIV ID="AnalysisSource" class="pv" STYLE="display:block">
-->
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/AnalysisSource">
		<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/AnalysisSource" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</xsl:when>
	<!-- If nothing to show in Analysis Source tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No analysis source information is available.
	</DIV>
	</xsl:otherwise>
    </xsl:choose>
		<DIV STYLE="text-align:center; color:blue;margin-left=0.6in">
			<B>________________</B>
		</DIV>
	<!-- Review
-->
	<DIV ID="Review" class="pv" STYLE="display:block">
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review">
		<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</xsl:when>
	<!-- If nothing to show in Review tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
             No Review information is available.
	</DIV>
	</xsl:otherwise>
    </xsl:choose>
	</DIV>

</DIV>
	<!-- Platform Tab -->
	<DIV ID="Platform" CLASS="pv" STYLE="display:none">
	<xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform">
	<!-- Show contents of platform tab -->
	<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
	</xsl:when>
	<!-- If nothing to show in platform tab, show message -->
	<xsl:otherwise>
	<DIV STYLE="text-align:center; color:#6495ED">
                No platform information is available.
    </DIV>
	</xsl:otherwise>
	</xsl:choose>
	<BR/>
</DIV>

	<!-- Attributes Tab -->
	<DIV ID="Attributes" class="pv" STYLE="display:none">
	<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/AdditionalAttributes[(
        		 AdditionalAttributeDataType   )
       			]">
										<!-- Show contents of Attributes tab -->
										<DIV CLASS="pe2" STYLE="margin-left=0.2in">
											<B>Collection Attributes </B>
											<DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
												<table border="1" width="80%" align="center" CLASS="mytable">
													<tr>
														<th> Class </th>
														<th> Name </th>
														<th> Description </th>
														<th> DataType </th>
													</tr>
													<xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/AdditionalAttributes" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
												</table>
											</DIV>
										</DIV>
									</xsl:when>
									<!-- If nothing to show in Attributes tab, show message -->
									<xsl:otherwise>
										<DIV STYLE="text-align:center; color:#6495ED">
                  No detailed attribute information is available.
                </DIV>
									</xsl:otherwise>
								</xsl:choose>
								<BR/>
							</DIV>
						</DIV>
					</xsl:otherwise>
				</xsl:choose>
			</BODY>
		</HTML>
	</xsl:template>
	<!-- DESCRIPTION TAB -->
	<!-- Local Granule  ID-->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule">
		<xsl:for-each select=".">
			<DIV CLASS="pe2" STYLE="margin-left=0.2in">
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/LocalGranuleID" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/SizeMBDataGranule" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/DayNightFlag" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/LocalVersionID" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/ProductionDateTime" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/ReprocessingPlanned" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
                <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/ReprocessingActual" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
			</DIV>
		</xsl:for-each>
	</xsl:template>


        <!-- LocalGranuleID-->
        <xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/LocalGranuleID">
                <xsl:for-each select=".">
                        <DIV>
                                <I>Local Granule ID= </I>
                                <SPAN STYLE="color:#999999">
                                        <xsl:value-of select="."/>
                                </SPAN>
                        </DIV>
                </xsl:for-each>
        </xsl:template>


	<!-- SizeMBDataGranule -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/SizeMBDataGranule">
		<xsl:for-each select=".">
			<DIV> 
				<I>Size MB ECS Data Granule = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>

	<!-- DayNightFlag -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/DayNightFlag">
		<xsl:for-each select=".">
			<DIV >
				<I>Day Night Flag = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>

	<!-- ProductionDateTime -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/ProductionDateTime">
		<xsl:for-each select=".">
			<DIV> 
				<I>Production Date Time = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>


	<!-- LocalVersionID-->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/LocalVersionID">
		<xsl:for-each select=".">
			<DIV> 
				<I>Local Version ID = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>

	<!-- ReprocessingPlanned -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/ReprocessingPlanned">
		<xsl:for-each select=".">
			<DIV> 
				<I>Reprocessing Planned = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>

	<!-- ReprocessingActual-->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/DataGranule/ReprocessingActual">
		<xsl:for-each select=".">
			<DIV> 
				<I>Reprocessing Actual = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>

	<!-- Discipline Topic Parameters -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/PSAs/PSA">
		<xsl:for-each select=".">
			<DIV CLASS="sr2">
				<SPAN STYLE="color:#999999">
					<tr>
						<td> <xsl:number /> </td>
						<td>
							<xsl:value-of select="PSAName"/>
						</td>
						<td>
							<xsl:value-of select="PSAValue"/>
						</td>
					</tr>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>
	<!-- Collection AdditionalAttributes -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/AdditionalAttributes">
		<xsl:for-each select=".">
			<DIV CLASS="sr2">
				<SPAN STYLE="color:#999999">
					<tr>
						<td width="5%">
							<xsl:number/>
						</td>
						<td width="20%">
							<xsl:value-of select="AdditionalAttributeName"/>
						</td>
						<td width="50%">
							<xsl:value-of select="AdditionalAttributeDescription"/>
						</td>
						<td width="25%">
							<xsl:value-of select="AdditionalAttributeDataType"/>
						</td>
					</tr>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>
	<!-- SPATIAL TAB -->
	<!-- SpatialCoverageType-->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/SpatialDomainContainer/HorizontalSpatialDomainContainer/SpatialCoverageType">
		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> Spatial Coverage Type =
      <xsl:for-each select=".">
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</xsl:for-each>
		</DIV>
	</xsl:template>

        <!-- Granule Locality -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/SpatialDomainContainer/HorizontalSpatialDomainContainer/GranuleLocality">
		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> Granule Locality =
      <xsl:for-each select=".">
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</xsl:for-each>
		</DIV>
	</xsl:template>

	<!-- Vertical Spatial Domain -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/VerticalSpatialDomain">
<DIV>
 <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
  <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsd"/></a></DIV> 
 <DIV CLASS="ph2">Vertical Spatial Domain</DIV>
    <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
	<xsl:for-each select="VerticalSpatialDomainContainer">
		<DIV CLASS="pe2" STYLE="margin-left:0.2in">
			<I>Type <xsl:value-of select="VerticalSpatialDomainType"/>:</I>
			<xsl:value-of select="VerticalSpatialDomainValue"/>
		</DIV>
	</xsl:for-each>
    </DIV>
 </DIV>
 </xsl:template>

	<!-- Horizontal Spatial Domain -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer">
<DIV>
 <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
  <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsd"/></a></DIV> 
 <DIV CLASS="ph2">Horizontal Spatial Domain</DIV>
    <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
				<xsl:for-each select="ZoneIdentifier">
					<DIV CLASS="pe2" STYLE="margin-left:0.2in">
						<I>Zone Identifier: </I>
						<xsl:value-of select="."/>
					</DIV>
				</xsl:for-each>
				 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
					<xsl:when test="current()[Point]">
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsdp"/></a></DIV> 
 <DIV CLASS="ph2">Points</DIV>
 <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
								<xsl:apply-templates select="Point[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
							</DIV>
						</DIV>
					</xsl:when>
		<xsl:otherwise>
	</xsl:otherwise>
</xsl:choose>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
					<xsl:when test="current()[Circle]">
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsdc"/></a></DIV> 
 <DIV CLASS="ph2">Circles</DIV>
 <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
								<xsl:apply-templates select="Circle[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
							</DIV>
						</DIV>
					</xsl:when>
					<xsl:otherwise>
						<!--
     <DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
     <DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
        <BR/><BR/>
              This document does not contain circle information that can be displayed.
            </DIV>
-->
					</xsl:otherwise>
				</xsl:choose>
				 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
					<xsl:when test="current()[BoundingRectangle]">
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsdr"/></a></DIV> 
 <DIV CLASS="ph2">Bounding Rectangle</DIV>
 <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
								<xsl:apply-templates select="BoundingRectangle[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
							</DIV>
						</DIV>
					</xsl:when>
					<xsl:otherwise>
						<!--
     <DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
        <BR/><BR/>
              This document does not contain bounding rectangle information that can be displayed.
            </DIV>
-->
					</xsl:otherwise>
				</xsl:choose>
				 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
					<xsl:when test="current()[GPolygon]">
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsdg"/></a></DIV> 
 <DIV CLASS="ph2">GPolygons</DIV>
  <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
								<xsl:apply-templates select="GPolygon[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
							</DIV>
						</DIV>
					</xsl:when>
					<xsl:otherwise>
						<!--
     <DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
        <BR/><BR/>
              This document does not contain GPolygons information that can be displayed.
            </DIV>
-->
					</xsl:otherwise>
				</xsl:choose>
				 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
					<xsl:when test="current()[Polygon]">
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="hsdpo"/></a></DIV> 
  <DIV CLASS="ph2">Polygons</DIV>
  <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
								<xsl:apply-templates select="Polygon[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
							</DIV>
						</DIV>
					</xsl:when>
					<xsl:otherwise>
						<!--
     <DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
        <BR/><BR/>
              This document does not contain bounding rectangle information that can be displayed.
            </DIV>
-->
					</xsl:otherwise>
				</xsl:choose>
			</DIV>
		</DIV>
	</xsl:template>
	<!-- Bounding Coordinates -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/BoundingRectangle">
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/BoundingRectangle/WestBoundingCoordinate">
			<DIV STYLE="margin-left:0.2in">
				<I>West Bounding Coordinate: </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/BoundingRectangle/NorthBoundingCoordinate">
			<DIV STYLE="margin-left:0.2in">
				<I>North Bounding Coordinate: </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/BoundingRectangle/EastBoundingCoordinate">
			<DIV STYLE="margin-left:0.2in">
				<I>East Bounding Coordinate: </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/BoundingRectangle/SouthBoundingCoordinate">
			<DIV STYLE="margin-left:0.2in">
				<I>South Bounding Coordinate: </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/Point -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Point">
		<DIV STYLE="margin-left:0.2in">
			<I>Point Longitude = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="PointLongitude[./.]"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>Point Latitude = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="PointLatitude[./.]"/>
			</SPAN>
		</DIV>
		<DIV STYLE="text-align:left; color:#6495ED">_______________________</DIV>
		<BR/>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/Circle -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Circle">
		<DIV STYLE="margin-left:0.2in">
			<I>Center Longitude = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Circle/CenterLongitude"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>Center Latitude = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Circle/CenterLatitude"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>Radius = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Circle/Radius"/>
			</SPAN>
		</DIV>
		<DIV STYLE="text-align:left; color:#6495ED">_______________________</DIV>
		<BR/>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon">
		<DIV STYLE="margin-left:0.4in">
			<I>
				<B>Boundaries </B>
			</I>
			<SPAN STYLE="color:#999999">
				<xsl:for-each select="Boundary">
					<xsl:apply-templates select="." xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
				</xsl:for-each>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.4in">
			<SPAN STYLE="color:#999999">
				<xsl:apply-templates select="ExclusiveZone" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
			</SPAN>
		</DIV>
<!--
		<DIV STYLE="text-align:left; color:red">
			<B>===================================================</B>
		</DIV>
-->
		<BR/>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon/Boundary -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon/Boundary">
		<DIV STYLE="margin-left:0.4in">
			<I>Boundary Points = </I>
			<BR/>
			<BR/>
			<SPAN STYLE="color:#999999">
				<table border="1" CLASS="mytable" >
					<th> Point Longitude </th>
					<th> Point Latitude </th>
					<xsl:for-each select="Point[. != '']">
						<tr>
							<td>
								<xsl:value-of select="PointLongitude[./.]"/>
							</td>
							<td>
								<xsl:value-of select="PointLatitude"/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</SPAN>
		</DIV>
	</xsl:template>

	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon/ExclusiveZone">
		<DIV STYLE="margin-left:0.4in">
			<SPAN STYLE="color:#999999">
			<I>
				<B>Exclusive Zone = </B>
			</I>
				<xsl:value-of select="." />
				<xsl:apply-templates select="Boundary[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
			</SPAN>
		</DIV>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon/ExclusiveZone/Boundary -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/GPolygon/ExclusiveZone/Boundary">
		<DIV STYLE="margin-left:0.4in">
			<I>Exclusive Zone Boundary Points = </I>
			<BR/>
			<BR/>
			<SPAN STYLE="color:#999999">
				<table border="1" CLASS="mytable">
					<th> Point Longitude </th>
					<th> Point Latitude </th>
					<xsl:for-each select="Point[. != '']">
						<tr>
							<td>
								<xsl:value-of select="PointLongitude[./.]"/>
							</td>
							<td>
								<xsl:value-of select="PointLatitude"/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</SPAN>
		</DIV>
	</xsl:template>
	<!-- Polygon -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon">
		 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<xsl:when test="current()[SinglePolygon]">
				<DIV CLASS="pe2">
					<B>
						<I>Single Polygon </I>
					</B>
					<xsl:apply-templates select="SinglePolygon[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
				</DIV>
			</xsl:when>
			<xsl:otherwise>
				<DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
					<BR/>
					<BR/>
              This document does not contain Single Polygons information that can be displayed.
            </DIV>
			</xsl:otherwise>
		</xsl:choose>
		 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<xsl:when test="current()[MultiplePolygon]">
				<DIV CLASS="pe2">
					<B>
						<I>Multiple Polygon </I>
					</B>
					<xsl:apply-templates select="MultiplePolygon[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
				</DIV>
			</xsl:when>
			<xsl:otherwise>
				<DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
					<BR/>
					<BR/>
              This document does not contain Multiple Polygons information that can be displayed.
            </DIV>
			</xsl:otherwise>
		</xsl:choose>
		<DIV STYLE="text-align:left; color:red">
			<B>=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=</B>
		</DIV>
		<BR/>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon/SinglePolygon -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Spatial/SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon/SinglePolygon">
		 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<xsl:when test="current()[InnerRing]">
				<DIV CLASS="pe2">
					<B>
						<I>Inner Ring </I>
					</B>
					<xsl:apply-templates select="InnerRing/Boundary[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
				</DIV>
			</xsl:when>
			<xsl:otherwise>
				<DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
					<BR/>
					<BR/>
              This document does not contain inner ring information that can be displayed.
            </DIV>
			</xsl:otherwise>
		</xsl:choose>
		 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<xsl:when test="current()[OutRing]">
				<DIV CLASS="pe2">
					<B>
						<I>Out Ring </I>
					</B>
					<xsl:apply-templates select="OutRing/Boundary[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
				</DIV>
			</xsl:when>
			<xsl:otherwise>
				<DIV STYLE="text-align:center; color:#6495ED; margin-left:1in; margin-right:1in">
					<BR/>
					<BR/>
              This document does not contain outer ring information that can be displayed.
            </DIV>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon/SinglePolygon/InnerRing/Boundary -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon/SinglePolygon/InnerRing/Boundary">
		<DIV STYLE="margin-left:0.4in">
			<I> Boundary Points = </I>
			<BR/>
			<BR/>
			<SPAN STYLE="color:#999999">
				<table border="1" CLASS="mytable">
					<th> Point Longitude </th>
					<th> Point Latitude </th>
					<xsl:for-each select="Point[. != '']">
						<tr>
							<td>
								<xsl:value-of select="PointLongitude[./.]"/>
							</td>
							<td>
								<xsl:value-of select="PointLatitude"/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</SPAN>
		</DIV>
	</xsl:template>
	<!-- SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon/SinglePolygon/OutRing/Boundary -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/SpatialDomainContainer/HorizontalSpatialDomainContainer/Polygon/SinglePolygon/OutRing/Boundary">
		<DIV STYLE="margin-left:0.4in">
			<I> Boundary Points = </I>
			<BR/>
			<BR/>
			<SPAN STYLE="color:#999999">
				<table border="1" CLASS="mytable">
					<th> Point Longitude </th>
					<th> Point Latitude </th>
					<xsl:for-each select="Point[. != '']">
						<tr>
							<td>
								<xsl:value-of select="PointLongitude[./.]"/>
							</td>
							<td>
								<xsl:value-of select="PointLatitude"/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</SPAN>
		</DIV>
	</xsl:template>

	<!-- Orbital Calculated Spatial Domain -->
<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/OrbitCalculatedSpatialDomain">
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="ocsd"/></a></DIV> 
 <DIV CLASS="ph2">Orbital Calculated Spatial Domain</DIV>
 <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/OrbitCalculatedSpatialDomain/OrbitCalculatedSpatialDomainContainer">
		<DIV CLASS="pe2" STYLE="display=block;margin-left=0.6in"> Orbit Number =
		<SPAN STYLE="color:#999999">
				<xsl:value-of select="OrbitNumber[. != '']"/>
			</SPAN>
			<BR/> Equator Crossing Longitude =
		<SPAN STYLE="color:#999999">
				<xsl:value-of select="EquatorCrossingLongitude[. != '']"/>
			</SPAN>
			<BR/> Equator Crossing Date =
      	<SPAN STYLE="color:#999999">
				<xsl:value-of select="EquatorCrossingDate[. != '']"/>
			</SPAN>
			<BR/> Equator Crossing Time=
      	<SPAN STYLE="color:#999999">
				<xsl:value-of select="EquatorCrossingTime[. != '']"/>
			</SPAN>
		</DIV>
		<DIV STYLE="text-align:left; color:blue;margin-left=0.6in">
			<B>________________________________________________________</B>
		</DIV>
	   </xsl:for-each>
		<BR/>
	</DIV>
	</DIV>
	</xsl:template>

	<!-- Measured Parameters -->
<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter">
<DIV STYLE="margin-left:0.0in"><B>Measured Parameters</B></DIV>
    <xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer">
    <DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}" name="ocsd"/></a></DIV>
     <DIV CLASS="ph2">Measured Parameter Container</DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
     Parameter Name = <xsl:value-of select="ParameterName[. != '']"/>
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
     </DIV>
    </DIV>
    </xsl:for-each>
</xsl:template>

<!-- ProcessingQA-->
<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA">
<DIV STYLE="margin-left:0.2in"><B>ProcessingQA: </B></DIV>
    <xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA/ProcessingQAContainer">
    <DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}" name="ocsd"/></a></DIV>
     <DIV CLASS="ph1">
	ProcessingQA Container	
     </DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA/ProcessingQAContainer/ProcessingQADescription" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA/ProcessingQAContainer/ProcessingQAAttribute" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
     </DIV>
    </DIV>
    </xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA/ProcessingQAContainer/ProcessingQADescription">
	<xsl:for-each select=".">
		<DIV> 
			<I>ProcessingQA Description= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/ProcessingQA/ProcessingQAContainer/ProcessingQAAttribute">
	<xsl:for-each select=".">
		<DIV> 
			<I>ProcessingQA Attribute= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<!-- Review-->
<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review">
<DIV STYLE="margin-left:0.0in"><B>Review </B></DIV>
    <xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer">
    <DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}" name="ocsd"/></a></DIV>
     <DIV CLASS="ph1">
	Review Container	
     </DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer/ScienceReviewStatus" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer/ScienceReviewDate" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
        <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer/FutureReviewDate" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
     </DIV>
    </DIV>
    </xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer/ScienceReviewStatus">
	<xsl:for-each select=".">
		<DIV> 
			<I>Science Review Status= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer/ScienceReviewDate">
	<xsl:for-each select=".">
		<DIV> 
			<I>Science Review Date= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Review/ReviewContainer/FutureReviewDate">
	<xsl:for-each select=".">
		<DIV> 
			<I>Future Review Date= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<!-- Analysis Source-->
<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/AnalysisSource">
<DIV STYLE="margin-left:0.2in"><B>Analysis Source </B></DIV>
   <DIV CLASS="pe2" >
		<DIV> 
			<I>Analysis Type= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="./AnalysisType"/>
			</SPAN>
		</DIV>
		<DIV> 
			<I>Analysis Short Name= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="./AnalysisShortName"/>
			</SPAN>
		</DIV>
		<DIV> 
			<I>Analysis Long Name= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="./AnalysisLongName"/>
			</SPAN>
		</DIV>
		<DIV> 
			<I>Analysis Technique= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="./AnalysisTechnique"/>
			</SPAN>
		</DIV>
</DIV>
</xsl:template>












<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats">
 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
 <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats[( QAPercentMissingData | QAPercentOutofBoundsData | QAPercentInterpolatedData | QAPercentCloudCover )
    ] "  >
<!-- Show contents of QAStats-->

<DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}"/></a></DIV>
     <DIV CLASS="ph2">QA Statistics</DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentMissingData" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentOutofBoundsData" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentInterpolatedData" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentCloudCover" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
     </DIV>
</DIV>
 </xsl:when>
 <xsl:otherwise>
   <DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}"/></a></DIV>
     <DIV CLASS="ph2">QA Stats</DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
        <SPAN STYLE="display:block; text-align:left; color:#6495ED">
                No QAStats information is available.
        </SPAN>
 </DIV>
 </DIV>
 </xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentMissingData">
	<xsl:for-each select=".">
		<DIV> 
			<I>Per Cent Missing Data = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentOutofBoundsData">
	<xsl:for-each select=".">
		<DIV> 
			<I>Per Cent Out of Bounds Data = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentInterpolatedData">
	<xsl:for-each select=".">
		<DIV> 
			<I>Per Cent Interpolate Data = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAStats/QAPercentCloudCover">
	<xsl:for-each select=".">
		<DIV> 
			<I>Per Cent  Cloud Cover = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags">
 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
        <xsl:when test="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlag[( AutomaticQualityFlag | AutomaticQualityFlagExplanation | OperationalQualityFlag | OperationalQualityFlagExplanation | ScienceQualityFlag | ScienceQualityFlagExplanation )
    ] "  >
<!-- Show contents of QAFlags-->
<DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}"/></a></DIV>
     <DIV CLASS="ph2">QA Flags</DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/AutomaticQualityFlag" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/AutomaticQualityFlagExplanation" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/OperationalQualityFlag" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/OperationalQualityFlagExplanation" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/ScienceQualityFlag" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
       <xsl:apply-templates select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/ScienceQualityFlagExplanation" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
     </DIV>
</DIV>
 </xsl:when>
 <xsl:otherwise>
   <DIV>
    <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
     <a onClick="flipArrow(this);"><img src="{$leftgif}"/></a></DIV>
     <DIV CLASS="ph2">QA Flags</DIV>
     <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
        <SPAN STYLE="display:block; text-align:left; color:#6495ED">
                No QAFlags information is available.
        </SPAN>
 </DIV>
 </DIV>
 </xsl:otherwise>
</xsl:choose>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/AutomaticQualityFlag">
	<xsl:for-each select=".">
		<DIV> 
			<I>Automatic Quality Flag = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/AutomaticQualityFlagExplanation">
	<xsl:for-each select=".">
		<DIV> 
			<I>Automatic Quality Flag Explanation= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/OperationalQualityFlag">
	<xsl:for-each select=".">
		<DIV> 
			<I>Operational Quality Flag = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/OperationalQualityFlagExplanation">
	<xsl:for-each select=".">
		<DIV> 
			<I>Operational Quality Flag Explanation= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>


<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/ScienceQualityFlag">
	<xsl:for-each select=".">
		<DIV> 
			<I>Science Quality Flag = </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/MeasuredParameter/MeasuredParameterContainer/QAFlags/ScienceQualityFlagExplanation">
	<xsl:for-each select=".">
		<DIV> 
			<I>Science Quality Flag Explanation= </I>
			<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
			</SPAN>
		</DIV>
	</xsl:for-each>
</xsl:template>

	<!-- TEMPORAL TAB -->

	<!-- Range Date Time -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime">
<DIV>
 <DIV CLASS="ph1" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="rdt"/></a></DIV> 
 <DIV CLASS="ph2">Range Date Time</DIV>
 <DIV CLASS="pe2" STYLE="display:none" controlled="yes">
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime/RangeBeginningDate">
			<DIV STYLE="margin-left:0.2in">
				<I>Range Beginning Date = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime/RangeBeginningTime">
			<DIV STYLE="margin-left:0.2in">
				<I>Range Beginning Time = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime/RangeEndingDate">
			<DIV STYLE="margin-left:0.2in">
				<I>Range Ending Date = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
		<xsl:for-each select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/RangeDateTime/RangeEndingTime">
			<DIV STYLE="margin-left:0.2in">
				<I>Range Ending Time = </I>
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</DIV>
	</DIV>
	</xsl:template>
	<!-- CONTACT TAB -->
	<!-- Contact-->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact">
<xsl:variable name="thisID" select="generate-id(.)"/>
<DIV>
<DIV CLASS="ph1" STYLE="float: left; position: relative; width:0" >
 <a onClick="flipArrow(this);"><img src="{$leftgif}"> 
<xsl:attribute name="name">
	<xsl:value-of select="$thisID"/>
</xsl:attribute>
</img></a>
</DIV> 
<DIV CLASS="ph2">Contact <xsl:number /> - <xsl:value-of select="Role" /></DIV>
<DIV CLASS="pe2" STYLE="display:none" controlled="yes">
	<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> <B> Role = </B>
      <xsl:for-each select="Role[. != '']">
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</xsl:for-each>
		</DIV>

		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> <B> Contact Instructions = </B>
      <xsl:for-each select="ContactInstructions[. != '']">
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</xsl:for-each>
		</DIV>
		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> <B> Contact Organization Name = </B>
      <xsl:for-each select="ContactOrganizationName[. != '']">
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
			</xsl:for-each>
		</DIV>
		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> 
		 <B>Contact Organization Address = </B>
				<xsl:apply-templates select="ContactOrganizationAddress[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
		</DIV>
		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> 
		 <B>Organization Telephone=</B> 

				<xsl:apply-templates select="OrganizationTelephone[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
		</DIV>
		<DIV CLASS="pe2" STYLE="margin-left:0.2in;display:block"> 
		<B>Organization E-Mail=</B>
				<xsl:apply-templates select="OrganizationEmail[ * != '']" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
		</DIV>
		<DIV STYLE="text-align:center; color:#6495ED">_________________</DIV>
		<BR/>
	</DIV>
</DIV>
	</xsl:template>

	<!-- ContactOrganizationAddress -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/ContactOrganizationAddress">
		<DIV STYLE="margin-left:0.2in">
			<I>Street Address = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/ContactOrganizationAddress/StreetAddress"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>City = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/ContactOrganizationAddress/City"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>State Province = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/ContactOrganizationAddress/StateProvince"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>Postal Code = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/ContactOrganizationAddress/PostalCode"/>
			</SPAN>
		</DIV>
		<DIV STYLE="margin-left:0.2in">
			<I>Country = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/ContactOrganizationAddress/Country"/>
			</SPAN>
		</DIV>
	</xsl:template>
	<!-- OrganizationTelephone -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/OrganizationTelephone">
		<DIV STYLE="margin-left:0.2in">
			<I>Telephone Number = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="TelephoneNumber"/>
			</SPAN>
			<I>, Telephone Number Type = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="TelephoneNumberType"/>
			</SPAN>
		</DIV>
	</xsl:template>
	<!-- OrganizationEmail -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/OrganizationEmail">
		<DIV STYLE="margin-left:0.2in">
			<I>Electronic Mail Address = </I>
			<SPAN STYLE="color:#999999">
				<xsl:value-of select="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/CollectionMetaData/Contact/OrganizationEmail/ElectronicMailAddress"/>
			</SPAN>
		</DIV>
	</xsl:template>




	<!-- PLATFORM TAB -->
	<!-- Platform Information -->
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform">
      	<xsl:for-each select="PlatformShortName[. != '']">
	<DIV CLASS="pe2" STYLE="margin-left:0.4in;display:block"> Platform Short Name =
		<SPAN STYLE="color:#999999">
		<xsl:value-of select="."/>
		</SPAN>
	</DIV>
	</xsl:for-each>
      	<xsl:for-each select="PlatformLongName[. != '']">
	<DIV CLASS="pe2" STYLE="margin-left:0.4in;display:block"> Platform Long Name =
		<SPAN STYLE="color:#999999">
		<xsl:value-of select="."/>
		</SPAN>
	</DIV>
	</xsl:for-each>
      	<xsl:for-each select="PlatformType[. != '']">
	<DIV CLASS="pe2" STYLE="margin-left:0.4in;display:block"> Platform Type =
		<SPAN STYLE="color:#999999">
		<xsl:value-of select="."/>
		</SPAN>
	</DIV>
	</xsl:for-each>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<xsl:when test="current()[PlatformCharacteristic]">
<DIV>
<DIV CLASS="ph2" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="pchar"/></a></DIV> 
 <DIV CLASS="ph2">Platform Characteristic</DIV>
 <DIV CLASS="pe2" STYLE="margin-left:0.4in;display:none" controlled="yes">
  <DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
					<table border="1" width="80%" align="center" CLASS="mytable">
						<tr>
							<th> Name </th>
							<th> Description</th>
							<th> DataType</th>
							<th> Unit</th>
							<th> Value</th>
						</tr>
						<xsl:apply-templates select="PlatformCharacteristic" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
					</table>
				</DIV>
	</DIV>
	</DIV>
			</xsl:when>
		</xsl:choose>
		<BR/>
<DIV>
<DIV CLASS="ph2" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="inst"/></a></DIV> 
 <DIV CLASS="ph2">Instrument</DIV>
 <DIV CLASS="pe2" STYLE="margin-left:0.4in;display:none" controlled="yes">
      		<xsl:for-each select="Instrument/InstrumentShortName[. != '']">
		<DIV CLASS="pe2" STYLE="margin-left:0.6in;display:block">Instrument Short Name =
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
		</DIV>
		</xsl:for-each>
      		<xsl:for-each select="Instrument/InstrumentLongName[. != '']">
		<DIV CLASS="pe2" STYLE="margin-left:0.6in;display:block"> Instrument Long Name =
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
		</DIV>
		</xsl:for-each>
      		<xsl:for-each select="Instrument/InstrumentTechnique[. != '']">
		<DIV CLASS="pe2" STYLE="margin-left:0.6in;display:block"> Instrument Technique =
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
		</DIV>
		</xsl:for-each>
      		<xsl:for-each select="Instrument/NumberOfSensors[. != '']">
		<DIV CLASS="pe2" STYLE="margin-left:0.6in;display:block"> Number of Sensors =
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
		</DIV>
		</xsl:for-each>
      		<xsl:for-each select="Instrument/OperationMode[. != '']">
		<DIV CLASS="pe2" STYLE="margin-left:0.6in;display:block"> Operation Mode =
				<SPAN STYLE="color:#999999">
					<xsl:value-of select="."/>
				</SPAN>
		</DIV>
		</xsl:for-each>
		 <xsl:variable name="instrument-characteristic" select="Instrument/InstrumentCharacteristic" />
		 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

			<xsl:when test="current()[Instrument/InstrumentCharacteristic]">

<DIV>			
<DIV CLASS="ph2" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="instchar"/></a></DIV> 
 <DIV CLASS="ph2">Instrument Characteristic</DIV>
 <DIV CLASS="pe2" STYLE="margin-left:0.6in;display:none" controlled="yes">
				<DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
					<table border="1" width="70%" align="center" CLASS="mytable">
						<tr>
							<th> Name </th>
							<th> Description</th>
							<th> DataType</th>
							<th> Unit</th>
							<th> Value</th>
						</tr>
						<xsl:apply-templates select="Instrument/InstrumentCharacteristic" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
					</table>
				</DIV>
				</DIV>
				</DIV>
			</xsl:when>
		</xsl:choose>
	<BR/>
		 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
			<xsl:when test="current()[Instrument/Sensor]">
<DIV>
<DIV CLASS="ph2" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="sensor"/></a></DIV> 
 <DIV CLASS="ph2">Sensor</DIV>
 <DIV CLASS="pe2" STYLE="margin-left:0.6in;display:none" controlled="yes">
				<DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
					<table border="1" width="70%" align="center" CLASS="mytable">
						<tr>
							<th> Sensor </th>
							<th> Short Name</th>
							<th> LongName</th>
							<th> Technique</th>
						</tr>
						<xsl:apply-templates select="Instrument/Sensor" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
					</table>
				</DIV>
				</DIV>
				</DIV>
			</xsl:when>
		</xsl:choose>
		<BR/>
	 <xsl:choose xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:when test="current()[Instrument/Sensor/SensorCharacteristic]">
<DIV>
<DIV CLASS="ph2" STYLE="float: left; position: relative; width:0">
 <a onClick="flipArrow(this);"><img src="{$leftgif}" name="sensorchar"/></a></DIV> 
 <DIV CLASS="ph2">Sensor Characteristic</DIV>
 <DIV CLASS="pe3" STYLE="margin-left:0.8in;display:none" controlled="yes">
				<DIV CLASS="lt" STYLE="display:block;position:relative;top:15;margin-left:0.05in;COLOR:#999999">
					<table border="1" width="70%" align="center" CLASS="mytable">
						<tr>
							<th> Name </th>
							<th> Description</th>
							<th> DataType</th>
							<th> Value</th>
						</tr>
						<xsl:apply-templates select="Instrument/Sensor/SensorCharacteristic" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"/>
					</table>
				</DIV>
				</DIV>
				</DIV>
			</xsl:when>
		</xsl:choose>
	 </DIV>
	</DIV>
	<DIV STYLE="text-align:left; color:blue;margin-left=0.6in">
			<B>_________________________________________________________________________</B>
	</DIV>
	</xsl:template>

	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform/PlatformCharacteristic">
		<xsl:for-each select=".">
			<DIV CLASS="sr2">
				<SPAN STYLE="color:#999999">
					<tr>
						<td>
							<xsl:value-of select="PlatformCharacteristicName"/>
						</td>
						<td>
							<xsl:value-of select="PlatformCharacteristicDescription"/>
						</td>
						<td>
							<xsl:value-of select="PlatformCharacteristicDataType"/>
						</td>
						<td>
							<xsl:value-of select="PlatformCharacteristicUnit"/>
						</td>
						<td>
							<xsl:value-of select="PlatformCharacteristicValue"/>
						</td>
					</tr>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform/Instrument/InstrumentCharacteristic">
		<xsl:for-each select=".">
			<DIV CLASS="sr2">
				<SPAN STYLE="color:#999999">
					<tr>
						<td>
							<xsl:value-of select="InstrumentCharacteristicName"/>
						</td>
						<td>
							<xsl:value-of select="InstrumentCharacteristicDescription"/>
						</td>
						<td>
							<xsl:value-of select="InstrumentCharacteristicDataType"/>
						</td>
						<td>
							<xsl:value-of select="InstrumentCharacteristicUnit"/>
						</td>
						<td>
							<xsl:value-of select="InstrumentCharacteristicValue"/>
						</td>
					</tr>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform/Instrument/Sensor">
			<DIV CLASS="sr2">
				<SPAN STYLE="color:#999999">
					<tr>
						<td>
							<xsl:number/>
						</td>
						<td>
							<xsl:value-of select="SensorShortName"/>
						</td>
						<td>
							<xsl:value-of select="SensorLongName"/>
						</td>
						<td>
							<xsl:value-of select="SensorTechnique"/>
						</td>
					</tr>
				</SPAN>
			</DIV>
	</xsl:template>
	<xsl:template match="/GranuleMetaDataFile/GranuleMetaDataSet/Granules/GranuleURMetaData/Platform/Instrument/Sensor/SensorCharacteristic">
		<xsl:for-each select=".">
			<DIV CLASS="sr2">
				<SPAN STYLE="color:#999999">
					<tr>
						<td>
							<xsl:value-of select="SensorCharacteristicName"/>
						</td>
						<td>
							<xsl:value-of select="SensorCharacteristicDescription"/>
						</td>
						<td>
							<xsl:value-of select="SensorCharacteristicDataType"/>
						</td>
						<td>
							<xsl:value-of select="SensorCharacteristicValue"/>
						</td>
					</tr>
				</SPAN>
			</DIV>
		</xsl:for-each>
	</xsl:template>


 <xsl:template match="instrument-characteristic">
			<DIV> HI </DIV>
		 </xsl:template>
</xsl:stylesheet>
